@@ -2,7 +2,7 @@ import os
 import numpy as np
 from PIL import Image
 
-print('1', os.getcwd())
+os.chdir(os.path.dirname(__file__))
 
 def func(x):
     #return -np.log(x*(-1)/255.1 + 1)
@@ -18,12 +18,7 @@ def NumOCR(path, label=None, debug=False, show=False):
     ImageFile.close()
 
     # Calling for trained model
-    print('2', os.getcwd())
-    try:
-        ThetaArray = np.load("theta.npy")
-    except:
-        os.chdir("./MNIST2")
-        ThetaArray = np.load("theta.npy")
+    ThetaArray = np.load("theta.npy")
 
     # Comparison
     ThetaArray = np.fabs(ThetaArray - ContentArray)
@@ -42,5 +37,4 @@ def NumOCR(path, label=None, debug=False, show=False):
         return True if Prediction == label else False
 
 if __name__ == "__main__":
-    print('3', os.getcwd())
     NumOCR("tmpl6deljrh.PNG", label=None, debug=False, show=False)
